@@ -5,14 +5,23 @@
 #'@return A list from 'OpenBlender' API (response).
 #'@keywords internal
 dameRespuestaLlamado <- function(url, data) {
-  data$json <- toJSON(data$json, auto_unbox = TRUE)
+  data$json <- toJSON(data$json, auto_unbox = TRUE, force = TRUE)
   resp <- POST(url = url, body = data, encode = "form")
-  # message(resp)
   if ("status" %in% attributes(content(resp))$names && content(resp)$status == "error") {
-    warning(content(resp))
+    warning("------------------------------------------------")
+    warning(paste("API call error: ", content(resp)$response))
+    warning("------------------------------------------------")
     return(FALSE)
   } else {
     cont <- content(resp)
+    # message(attributes(cont)$names)
+    # if ("base64_zip" %in% attributes(cont)$names) {
+    #   message(cont$base64_zip)
+    #   raw_chars <- charToRaw(cont$base64zip)
+    #   message(raw_chars)
+    #   cont <- unserialize(base64_dec(raw_chars))
+    #   message(cont)
+    # }
     if ("sample" %in% attributes(cont)$names) {
       sample <- toJSON(cont$sample, dataframe = "rows")
       sample <- fromJSON(sample)
